#!/usr/bin/env python
# -*- coding: utf-8 -*-

HBN_BLOCKEXPLORER = 'http://hbn.blockx.info/get/chain/HoboNickels/q/'
CRYPTOCOIN_API = 'http://www.cryptocoincharts.info/v2/api/tradingPair/'

def blockexplorer(*suffix):
	"""Returns the entrypoint URL for the Hobonickels block API.
	   All data provided by hbn.blockx.info.
	   http://www.worldcoinexplorer.com
	"""
	
	return HBN_BLOCKEXPLORER + '/'.join(suffix)

def exchange(*suffix):
	"""Returns the entrypoint URL for the Worldcoin price API.
	   All data provided by CryptoCoin.
	   http://www.cryptocoincharts.info
	"""
	
	return CRYPTOCOIN_API + '/'.join(suffix)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#     __          __                _      __        __    
#    / /_  ____  / /_  ____  ____  (_)____/ /_____  / /____
#   / __ \/ __ \/ __ \/ __ \/ __ \/ / ___/ //_/ _ \/ / ___/
#  / / / / /_/ / /_/ / /_/ / / / / / /__/ ,< /  __/ (__  ) 
# /_/ /_/\____/_.___/\____/_/ /_/_/\___/_/|_|\___/_/____/ 

__title__   = 'hobonickels'
__version__ = '0.3'
__author__  = '@c0ding'
__repo__    = 'https://github.com/c0ding/hobonickels-api'
__license__ = 'Apache v2.0 License'

import hobonickels_utils
from hobonickels_api import (
	about, difficulty, hashrate, block_count, total_coins, addressbalance,
	addresstohash, checkaddress, getreceivedbyaddress, getsentbyaddress,
	hashpubkey, hashtoaddress, translate_address, to_btc
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
sys.path.insert(0, os.path.abspath('..'))
import unittest
import hobonickels

__title__   = 'hobonickels'
__version__ = '0.3'
__author__  = '@c0ding'
__repo__    = 'https://github.com/c0ding/hobonickels-api'
__license__ = 'Apache v2.0 License'

class hobonickelstestsuite(unittest.TestCase):

	_multiprocess_can_split_ = True

	def test_difficulty(self):
		hobonickels.difficulty()
		assert type(hobonickels.difficulty()) is float
	
	def test_hashrate(self):
		hobonickels.hashrate()
		assert type(hobonickels.hashrate()) is str

	def test_block_count(self):
		hobonickels.block_count()
		assert type(hobonickels.block_count()) is float

	def test_total_coins(self):
		hobonickels.total_coins()
		assert type(hobonickels.total_coins()) is float
		
	def test_addressbalance(self):
		hobonickels.addressbalance('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')
		assert type(hobonickels.addressbalance('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')) is float
		
	def test_addresstohash(self):
		hobonickels.addresstohash('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')
		assert type(hobonickels.addresstohash('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')) is str
		
	def test_checkaddress(self):
		hobonickels.checkaddress('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')
		assert type(hobonickels.checkaddress('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')) is str
		
	def test_getreceivedbyaddress(self):
		hobonickels.getreceivedbyaddress('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')
		assert type(hobonickels.getreceivedbyaddress('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')) is str
		
	def test_getsentbyaddress(self):
		hobonickels.getsentbyaddress('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')
		assert type(hobonickels.getsentbyaddress('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')) is str
		
	def test_hashpubkey(self):
		hobonickels.hashpubkey('74BCE81E8F8FAAD31F32882132D3366CAA65EE46')
		assert type(hobonickels.hashpubkey('74BCE81E8F8FAAD31F32882132D3366CAA65EE46')) is str
		
	def test_hashtoaddress(self):
		hobonickels.hashtoaddress('74BCE81E8F8FAAD31F32882132D3366CAA65EE46')
		assert type(hobonickels.hashtoaddress('74BCE81E8F8FAAD31F32882132D3366CAA65EE46')) is str
		
	def test_translate_address(self):
		hobonickels.translate_address('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')
		assert type(hobonickels.translate_address('Es8mAQxXCKHA7YPnBhy4SzhLrmCH27sRu6')) is str
		
	def test_to_btc(self):
		hobonickels.to_btc()
		assert type(hobonickels.to_btc()) is dict

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from distutils.core import setup

setup(
    name = 'hobonickels',
    version = '0.3',
    url = 'https://github.com/c0ding/hobonickels-api',
    download_url = 'https://github.com/c0ding/hobonickels-api/archive/master.zip',
    author = 'c0ding',
    author_email = 'me@martinsimon.me',
    license = 'Apache v2.0 License',
    packages = ['hobonickels'],
    description = 'Python API for the Hobonickels cryptocurrency.',
    long_description = file('README.md','r').read(),
    keywords = ['HBN', 'Hobonickels', 'LTC', 'Litecoin', 'BTC', 'Bitcoin', 'DOGE', 'Dogecoin', 'WDC', 'Worldcoin', 'cryptocurrency', 'API'],
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import json
import urllib
from hobonickels_utils import exchange
from hobonickels_utils import blockexplorer

__title__   = 'hobonickels'
__version__ = '0.3'
__author__  = '@c0ding'
__repo__    = 'https://github.com/c0ding/hobonickels-api'
__license__ = 'Apache v2.0 License'


def about():
	"""Returns some information about the hobonickels module."""

	return '{} v.{} is maintained by {} and available at {}.'.format(__title__, __version__, __author__, __repo__)


def difficulty():
	"""Returns the current network difficulty."""

	d = urllib.urlopen(blockexplorer('getdifficulty'))
	return float(d.read())


def hashrate():
	"""Returns the current network hashrate."""

	c = block_count()
	blocks = "%.0f" %c
	d = urllib.urlopen(blockexplorer('nethash') + '/' + str(blocks))
	last_line = d.readlines()[-1]
	e = last_line.split(',')
	return e[-1]


def block_count():
	"""Returns the number of blocks in the longest block chain.
	   Equivalent to Bitcoin's getblockcount.
	"""

	d = urllib.urlopen(blockexplorer('getblockcount'))
	return float(d.read())


def total_coins():
	"""Returns the number of Hobonickels mined."""
	
	d = urllib.urlopen(blockexplorer('totalbc'))
	return float(d.read())


def addressbalance(PARAMETER):
	"""Returns the address balance.
	   [PARAMETER] is required and should be a HBN address.
	"""
	
	d = urllib.urlopen(blockexplorer('addressbalance') + '/' + str(PARAMETER))
	return float(d.read())


def addresstohash(PARAMETER):
	"""Returns the public key hash encoded in an address.
	   [PARAMETER] is required and should be a HBN address.
	"""
	
	d = urllib.urlopen(blockexplorer('addresstohash') + '/' + str(PARAMETER))
	return d.read()


def checkaddress(PARAMETER):
	"""Checks if specified address is valid and returns
	   _pubkeyhash_version_byte.
	   [PARAMETER] is required and can be any crypto address.
	"""

	d = urllib.urlopen(blockexplorer('checkaddress') + '/' + str(PARAMETER))
	return d.read()
	

# disabled as function is duplicate of checkaddress()
# def decode_address(PARAMETER):
#	 """Returns the version prefix and hash encoded in an address
#	    [PARAMETER] is required and can be any crypto address.
#	 """
#
#	 d = urllib.urlopen(blockexplorer('decode_address') + '/' + str(PARAMETER))
#	 return d.read()


def getreceivedbyaddress(PARAMETER):
	"""Returns amount of HBN received by an address.
	   [PARAMETER] is required and should be a HBN address.
	"""

	d = urllib.urlopen(blockexplorer('getreceivedbyaddress') + '/' + str(PARAMETER))
	return d.read()


def getsentbyaddress(PARAMETER):
	"""Returns amount of HBN sent by an address.
	   [PARAMETER] is required and should be a HBN address.
	"""

	d = urllib.urlopen(blockexplorer('getsentbyaddress') + '/' + str(PARAMETER))
	return d.read()


def hashpubkey(PARAMETER):
	"""Returns the 160-bit hash of PUBKEY.
	   [PARAMETER] is required and should be a PUBKEY.
	"""

	d = urllib.urlopen(blockexplorer('hashpubkey') + '/' + str(PARAMETER))
	return d.read()


def hashtoaddress(PARAMETER):
	"""Converts a 160-bit hash to an address.
	   [PARAMETER] is required and should be an address hash.
	"""

	d = urllib.urlopen(blockexplorer('hashtoaddress') + '/' + str(PARAMETER))
	return d.read()


def translate_address(PARAMETER):
	"""Translates address for use in HBN chain
	   [PARAMETER] is required and can be any crypto address.
	"""

	d = urllib.urlopen(blockexplorer('translate_address') + '/' + str(PARAMETER))
	return d.read()


def to_btc():
	"""Returns array with trading pair object."""
	
	d = urllib.urlopen(exchange('hbn_btc'))
	return json.loads(d.read())
